==> v-sim_3.3.3.orig.tar.gz: v_sim-3.3.3/src/panelModules/gtkAtomic.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef ATOMIC_GTK_H
#define ATOMIC_GTK_H


/* This .h and .c give functions to create a gtk interface
   to adjust resources values introduced with the
   atomic render method. */

#include <visu_elements.h>

#include <gtk/gtk.h>

/***************/
/* Public part */
/***************/

/* Initialise the specific area in the element panel
   for the atomic rendering method. */
void initAtomic_gtkPanel();

/* Initialise the gtk methods associated with
   the atomic rendering method. */
void initAtomic_gtkMain();

/* Create the gtk widgets (a hbox with a spin with
   positive values) and return it. */
GtkWidget* createGtkInterfaceForAtomicMethod();
/* changed the value in the spin box, reading the one given
   by the specified element. */
void onElementChange_atomicMethod(GList *eleList);
   
#endif

==> v-sim_3.4.4.orig.tar.gz: v_sim-3.4.4/src/panelModules/gtkAtomic.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef ATOMIC_GTK_H
#define ATOMIC_GTK_H


/* This .h and .c give functions to create a gtk interface
   to adjust resources values introduced with the
   atomic render method. */

#include <visu_elements.h>

#include <gtk/gtk.h>

/***************/
/* Public part */
/***************/

/**
 * panelElementAtomicInit_gtkPanel:
 *
 * Initialise the specific area in the element panel
 * for the atomic rendering method.
 */
void panelElementAtomicInit_gtkPanel();

/**
 * panelElementAtomicInit_gtkMain:
 *
 * Initialise the gtk methods associated with
 * the atomic rendering method.
 */
void panelElementAtomicInit_gtkMain();

/**
 * panelElementAtomicCreate_gtkInterface:
 * 
 * Create the gtk widgets (a hbox with a spin with
 *  positive values) and return it.
 *
 * Returns: newly created widgets to handle atomic rendering
 * characteristics of elements.
 */
GtkWidget* panelElementAtomicCreate_gtkInterface();

/**
 * panelElementAtomicCallback_onElementChange:
 * @eleList: a list of #VisuElement.
 *
 * Call this routine with a list of #VisuElement to change the values
 * shown in the widgets controling the atomic rendering. The values to
 * be put are read from the first #VisuElement of the list. The list
 * is then stored for future changes to the widgets will be applied to
 * all these elements.
 */
void panelElementAtomicCallback_onElementChange(GList *eleList);
   
#endif
